__author__ = 'alainivars'


ADMINS = (
    ('Alain Ivars', 'contact@mydomain.com'),
)

CONTACT_FORM_SUBJECT_TEMPLATE_NAME = 'email_subject.txt'
CONTACT_FORM_MESSAGE_TEMPLATE_NAME = 'email_message.txt'

COMPANY_INFOS = {
    'NAME': "my company",
    'ADDRESS': "26 streets from here th there",
    'ZIP': "1234",
    'CITY': "Maybe-there",
    'LAT': 48.81484460000001,
    'LNG': 2.0523723999999675,
    'PHONE': "+336 1234 5678",
    'EMAIL': 'contact@mycompany.com',
    'FACEBOOK': "Maybe-there",
    'LINKEDIN': "Maybe-there",
    'TWITTER': "Maybe-there",
    'GOOGLEPLUS': "+Maybe-there",
}

CRISPY_TEMPLATE_PACK = 'bootstrap3'
