{% extends "layout.html" %}
{% load i18n %}
{% block title %}{{ siteName }} - {% trans "Contact Completed" %}{% endblock %}

{% block content %}
<div class="container">
    <div class="row">
        <div class="col-lg-12">
            <h1 class="page-header">Contact <small>{% trans "Thank, it good to Hear From You!" %}</small></h1>
            <ol class="breadcrumb">
                <li><a href="index.html">{% trans "Home" %}</a></li>
            <li class="active">{% trans "Contact Completed" %}</li>
            </ol>
        </div>
        <div class="col-lg-12">
            <p>{% trans "Thank you! Your message was sent successfully." %}</p>
        </div>
    </div><!-- /.row -->
</div><!-- /.container -->
{% endblock content %}
